@@ -3,21 +3,21 @@
 "Service"
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.model.cacheable import Cacheable
+from trytond.pyson import Eval
 
 
 class Employee(ModelSQL, ModelView, Cacheable):
     _name = 'company.employee'
 
-    cost_price = fields.Function('get_cost_price', string='Cost Price',
-            type='numeric', digits="(16, currency_digits)",
-            depends=['currency_digits'],
-            help="Hourly cost price for this Employee")
+    cost_price = fields.Function(fields.Numeric('Cost Price',
+        digits=(16, Eval('currency_digits', 2)), depends=['currency_digits'],
+        help="Hourly cost price for this Employee"), 'get_cost_price')
     cost_prices = fields.One2Many('company.employee_cost_price', 'employee',
             'Cost Prices', help="List of hourly cost price over time")
-    currency_digits = fields.Function('get_currency_digits', type='integer',
-            string='Currency Digits', on_change_with=['company'])
+    currency_digits = fields.Function(fields.Integer('Currency Digits',
+        on_change_with=['company']), 'get_currency_digits')
 
-    def get_cost_price(self, cursor, user, ids, name, arg, context=None):
+    def get_cost_price(self, cursor, user, ids, name, context=None):
         '''
         Return the cost price at the date given in the context or the
         current date
@@ -64,14 +64,13 @@ class Employee(ModelSQL, ModelView, Cacheable):
                     break
         return cost
 
-    def get_currency_digits(self, cursor, user, ids, name, arg, context=None):
+    def get_currency_digits(self, cursor, user, ids, name, context=None):
         res = {}
         for employee in self.browse(cursor, user, ids, context=context):
             res[employee.id] = employee.company.currency.digits
         return res
 
-    def on_change_with_currency_digits(self, cursor, user, ids, vals,
-            context=None):
+    def on_change_with_currency_digits(self, cursor, user, vals, context=None):
         company_obj = self.pool.get('company.company')
         if vals.get('company'):
             company = company_obj.browse(cursor, user, vals['company'],
@@ -99,12 +98,13 @@ class EmployeeCostPrice(ModelSQL, ModelView):
     _description = __doc__
     _rec_name = 'date'
     date = fields.Date('Date', required=True, select=1)
-    cost_price = fields.Numeric('Cost Price', digits="(16, currency_digits)",
+    cost_price = fields.Numeric('Cost Price',
+            digits=(16, Eval('currency_digits', 2)),
             required=True, depends=['currency_digits'],
             help="Hourly cost price")
     employee = fields.Many2One('company.employee', 'Employee')
-    currency_digits = fields.Function('get_currency_digits', type='integer',
-            string='Currency Digits', on_change_with=['employee'])
+    currency_digits = fields.Function(fields.Integer('Currency Digits',
+        on_change_with=['employee']), 'get_currency_digits')
 
     def __init__(self):
         super(EmployeeCostPrice, self).__init__()
@@ -133,14 +133,13 @@ class EmployeeCostPrice(ModelSQL, ModelView):
         return super(EmployeeCostPrice , self).write(cursor, user, ids, vals,
                 context=context)
 
-    def get_currency_digits(self, cursor, user, ids, name, arg, context=None):
+    def get_currency_digits(self, cursor, user, ids, name, context=None):
         res = {}
         for costprice in self.browse(cursor, user, ids, context=context):
             res[costprice.id] = costprice.employee.company.currency.digits
         return res
 
-    def on_change_with_currency_digits(self, cursor, user, ids, vals,
-            context=None):
+    def on_change_with_currency_digits(self, cursor, user, vals, context=None):
         employee_obj = self.pool.get('company.employee')
         if vals.get('employee'):
             employee = employee_obj.browse(cursor, user, vals['employee'],
